@@ -280,42 +280,42 @@ void Compiler::generateWidgetCode(Tree fulllabel, Tree varname, Tree sig)
     } else if (isSigVSlider(sig, path, c, x, y, z)) {
         fClass->incUIActiveCount();
         fClass->addUICode(subst("ui_interface->addVerticalSlider(\"$0\", &$1, $2, $3, $4, $5);",
-                                checkNullLabel(varname, label), tree2str(varname), T(tree2float(c)), T(tree2float(x)),
-                                T(tree2float(y)), T(tree2float(z))));
-        fJSON.addVerticalSlider(checkNullLabel(varname, label).c_str(), NULL, (float)tree2float(c),
-                                (float)tree2float(x), (float)tree2float(y), (float)tree2float(z));
+                                checkNullLabel(varname, label), tree2str(varname), T(tree2double(c)), T(tree2double(x)),
+                                T(tree2double(y)), T(tree2double(z))));
+        fJSON.addVerticalSlider(checkNullLabel(varname, label).c_str(), NULL, (float)tree2double(c),
+                                (float)tree2double(x), (float)tree2double(y), (float)tree2double(z));
 
     } else if (isSigHSlider(sig, path, c, x, y, z)) {
         fClass->incUIActiveCount();
         fClass->addUICode(subst("ui_interface->addHorizontalSlider(\"$0\", &$1, $2, $3, $4, $5);",
-                                checkNullLabel(varname, label), tree2str(varname), T(tree2float(c)), T(tree2float(x)),
-                                T(tree2float(y)), T(tree2float(z))));
-        fJSON.addHorizontalSlider(checkNullLabel(varname, label).c_str(), NULL, (float)tree2float(c),
-                                  (float)tree2float(x), (float)tree2float(y), (float)tree2float(z));
+                                checkNullLabel(varname, label), tree2str(varname), T(tree2double(c)), T(tree2double(x)),
+                                T(tree2double(y)), T(tree2double(z))));
+        fJSON.addHorizontalSlider(checkNullLabel(varname, label).c_str(), NULL, (float)tree2double(c),
+                                  (float)tree2double(x), (float)tree2double(y), (float)tree2double(z));
 
     } else if (isSigNumEntry(sig, path, c, x, y, z)) {
         fClass->incUIActiveCount();
         fClass->addUICode(subst("ui_interface->addNumEntry(\"$0\", &$1, $2, $3, $4, $5);",
-                                checkNullLabel(varname, label), tree2str(varname), T(tree2float(c)), T(tree2float(x)),
-                                T(tree2float(y)), T(tree2float(z))));
-        fJSON.addNumEntry(checkNullLabel(varname, label).c_str(), NULL, (float)tree2float(c), (float)tree2float(x),
-                          (float)tree2float(y), (float)tree2float(z));
+                                checkNullLabel(varname, label), tree2str(varname), T(tree2double(c)), T(tree2double(x)),
+                                T(tree2double(y)), T(tree2double(z))));
+        fJSON.addNumEntry(checkNullLabel(varname, label).c_str(), NULL, (float)tree2double(c), (float)tree2double(x),
+                          (float)tree2double(y), (float)tree2double(z));
 
     } else if (isSigVBargraph(sig, path, x, y, z)) {
         fClass->incUIPassiveCount();
         fClass->addUICode(subst("ui_interface->addVerticalBargraph(\"$0\", &$1, $2, $3);",
-                                checkNullBargraphLabel(varname, label, 1), tree2str(varname), T(tree2float(x)),
-                                T(tree2float(y))));
-        fJSON.addVerticalBargraph(checkNullLabel(varname, label).c_str(), NULL, (float)tree2float(x),
-                                  (float)tree2float(y));
+                                checkNullBargraphLabel(varname, label, 1), tree2str(varname), T(tree2double(x)),
+                                T(tree2double(y))));
+        fJSON.addVerticalBargraph(checkNullLabel(varname, label).c_str(), NULL, (float)tree2double(x),
+                                  (float)tree2double(y));
 
     } else if (isSigHBargraph(sig, path, x, y, z)) {
         fClass->incUIPassiveCount();
         fClass->addUICode(subst("ui_interface->addHorizontalBargraph(\"$0\", &$1, $2, $3);",
-                                checkNullBargraphLabel(varname, label, 0), tree2str(varname), T(tree2float(x)),
-                                T(tree2float(y))));
-        fJSON.addHorizontalBargraph(checkNullLabel(varname, label).c_str(), NULL, (float)tree2float(x),
-                                    (float)tree2float(y));
+                                checkNullBargraphLabel(varname, label, 0), tree2str(varname), T(tree2double(x)),
+                                T(tree2double(y))));
+        fJSON.addHorizontalBargraph(checkNullLabel(varname, label).c_str(), NULL, (float)tree2double(x),
+                                    (float)tree2double(y));
 
     } else if (isSigSoundfile(sig, path)) {
         fClass->incUIActiveCount();
@@ -384,23 +384,23 @@ void Compiler::generateWidgetMacro(const string& pathname, Tree fulllabel, Tree
 
     } else if (isSigVSlider(sig, path, c, x, y, z)) {
         fClass->addUIMacro(subst("FAUST_ADDVERTICALSLIDER(\"$0\", $1, $2, $3, $4, $5);", pathlabel, tree2str(varname),
-                                 T(tree2float(c)), T(tree2float(x)), T(tree2float(y)), T(tree2float(z))));
+                                 T(tree2double(c)), T(tree2double(x)), T(tree2double(y)), T(tree2double(z))));
 
     } else if (isSigHSlider(sig, path, c, x, y, z)) {
         fClass->addUIMacro(subst("FAUST_ADDHORIZONTALSLIDER(\"$0\", $1, $2, $3, $4, $5);", pathlabel, tree2str(varname),
-                                 T(tree2float(c)), T(tree2float(x)), T(tree2float(y)), T(tree2float(z))));
+                                 T(tree2double(c)), T(tree2double(x)), T(tree2double(y)), T(tree2double(z))));
 
     } else if (isSigNumEntry(sig, path, c, x, y, z)) {
         fClass->addUIMacro(subst("FAUST_ADDNUMENTRY(\"$0\", $1, $2, $3, $4, $5);", pathlabel, tree2str(varname),
-                                 T(tree2float(c)), T(tree2float(x)), T(tree2float(y)), T(tree2float(z))));
+                                 T(tree2double(c)), T(tree2double(x)), T(tree2double(y)), T(tree2double(z))));
 
     } else if (isSigVBargraph(sig, path, x, y, z)) {
         fClass->addUIMacro(subst("FAUST_ADDVERTICALBARGRAPH(\"$0\", $1, $2, $3);", pathlabel, tree2str(varname),
-                                 T(tree2float(x)), T(tree2float(y))));
+                                 T(tree2double(x)), T(tree2double(y))));
 
     } else if (isSigHBargraph(sig, path, x, y, z)) {
         fClass->addUIMacro(subst("FAUST_ADDHORIZONTALBARGRAPH(\"$0\", $1, $2, $3);", pathlabel, tree2str(varname),
-                                 T(tree2float(x)), T(tree2float(y))));
+                                 T(tree2double(x)), T(tree2double(y))));
 
     } else if (isSigSoundfile(sig, path)) {
         fClass->addUIMacro(subst("FAUST_ADDSOUNDFILE(\"$0\", $1);", pathlabel, tree2str(varname)));
