@@ -258,16 +258,7 @@ dsp_factory_base* InterpreterCodeContainer<REAL>::produceFactory()
                 getInterpreterVisitor<REAL>()->getFieldOffset("count"), getInterpreterVisitor<REAL>()->getFieldOffset("IOTA"),
                 INTER_MAX_OPT_LEVEL, metadata_block, getInterpreterVisitor<REAL>()->fUserInterfaceBlock, init_static_block,
                 init_block, resetui_block, clear_block, compute_control_block, compute_dsp_block);
-
-        case 7:
-            return new interpreter_dsp_factory_aux<REAL, 7>(
-                name, compile_options.str(), "", INTERP_FILE_VERSION, fNumInputs, fNumOutputs,
-                getInterpreterVisitor<REAL>()->fIntHeapOffset, getInterpreterVisitor<REAL>()->fRealHeapOffset,
-                getInterpreterVisitor<REAL>()->getFieldOffset("fSampleRate"),
-                getInterpreterVisitor<REAL>()->getFieldOffset("count"), getInterpreterVisitor<REAL>()->getFieldOffset("IOTA"),
-                INTER_MAX_OPT_LEVEL, metadata_block, getInterpreterVisitor<REAL>()->fUserInterfaceBlock, init_static_block,
-                init_block, resetui_block, clear_block, compute_control_block, compute_dsp_block);
-            
+        
         default:
             // Default case, no trace...
             return new interpreter_dsp_factory_aux<REAL, 0>(
