@@ -43,6 +43,7 @@
 #include <llvm/IR/LegacyPassNameParser.h>
 #include <llvm/IR/Verifier.h>
 #include <llvm/IR/PassManager.h>
+#include <llvm/IR/Constants.h>
 #include <llvm/IRReader/IRReader.h>
 #include <llvm/Linker/Linker.h>
 #include <llvm/Support/FileSystem.h>
@@ -97,6 +98,18 @@ using namespace std;
         cout << out_str.str() << endl;   \
     }
 
+// Assuming there is a single JSON string in the module
+std::string llvm_dsp_factory_aux::findJSON(llvm::Module* module)
+{
+    for (const auto& global : module->globals()) {
+        auto* initializer = global.getInitializer();
+        if (auto* array = llvm::dyn_cast<llvm::ConstantDataArray>(initializer)) {
+            if (array->isString()) return array->getAsString().str();
+        }
+    }
+    return "";
+}
+
 static void splitTarget(const string& target, string& triple, string& cpu)
 {
     size_t pos1 = target.find_first_of(':');
@@ -304,8 +317,7 @@ bool llvm_dynamic_dsp_factory_aux::initJIT(string& error_msg)
     
     targetOptions.GuaranteedTailCallOpt = true;
     
-    string debug_var = (getenv("FAUST_DEBUG")) ? string(getenv("FAUST_DEBUG")) : "";
-    if ((debug_var != "") && (debug_var.find("FAUST_LLVM3") != string::npos)) {
+    if (global::isDebug("FAUST_LLVM3")) {
 #if LLVM_VERSION_MAJOR < 12
         targetOptions.PrintMachineCode = true;
 #endif
@@ -352,14 +364,13 @@ bool llvm_dynamic_dsp_factory_aux::initJIT(string& error_msg)
         fOptLevel = std::min(fOptLevel, 3);
         ModulePassManager MPM = PB.buildPerModuleDefaultPipeline(opt_table[fOptLevel]);
         
-        if ((debug_var != "") && (debug_var.find("FAUST_LLVM1") != string::npos)) {
+        if (global::isDebug("FAUST_LLVM1")) {
             dumpLLVM(fModule);
         }
         
         // Optimize the IR
         MPM.run(*fModule, MAM);
-        
-        if ((debug_var != "") && (debug_var.find("FAUST_LLVM2") != string::npos)) {
+        if (global::isDebug("FAUST_LLVM2")) {
             dumpLLVM(fModule);
         }
 #else
@@ -379,7 +390,7 @@ bool llvm_dynamic_dsp_factory_aux::initJIT(string& error_msg)
             AddOptimizationPasses(pm, fpm, fOptLevel, 0);
         }
 
-        if ((debug_var != "") && (debug_var.find("FAUST_LLVM1") != string::npos)) {
+        if (global::isDebug("FAUST_LLVM1")) {
             dumpLLVM(fModule);
         }
 
@@ -390,14 +401,14 @@ bool llvm_dynamic_dsp_factory_aux::initJIT(string& error_msg)
         fpm.doFinalization();
         pm.add(createVerifierPass());
 
-        if ((debug_var != "") && (debug_var.find("FAUST_LLVM4") != string::npos)) {
+        if (global::isDebug("FAUST_LLVM4")) {
             // TODO
             // tm->addPassesToEmitFile(pm, fouts(), TargetMachine::CGFT_AssemblyFile, true);
         }
 
         // Now that we have all of the passes ready, run them.
         pm.run(*fModule);
-        if ((debug_var != "") && (debug_var.find("FAUST_LLVM2") != string::npos)) {
+        if (global::isDebug("FAUST_LLVM2")) {
             dumpLLVM(fModule);
         }
 #endif
@@ -563,7 +574,7 @@ static llvm_dsp_factory* readDSPFactoryFromIRAux(MEMORY_BUFFER buffer, const str
     }
 }
 
-// Helper functions
+// Helper public functions
 ModulePTR loadSingleModule(const string filename, LLVMContext* context)
 {
     SMDiagnostic err;
@@ -587,7 +598,7 @@ ModulePTR loadModule(const string& module_name, LLVMContext* context)
         return nullptr;
     }
 }
-
+        
 bool linkModules(Module* dst, ModulePTR src, string& error)
 {
     bool res = false;
