@@ -499,7 +499,7 @@ void global::reset()
 
     gAutoDifferentiate = false;
 
-    gLatexDocSwitch = true;         // Only LaTeX outformat is handled for the moment.
+    gLatexDocSwitch = true;  // Only LaTeX outformat is handled for the moment.
 
     gFileNum = 0;
 
@@ -648,9 +648,7 @@ void global::init()
     gDocTextsDefaultFile = "mathdoctexts-default.txt";
 
     gCurrentLocal = setlocale(LC_ALL, NULL);
-    if (gCurrentLocal != NULL) {
-        gCurrentLocal = strdup(gCurrentLocal);
-    }
+    if (gCurrentLocal != NULL) { gCurrentLocal = strdup(gCurrentLocal); }
 
     // Setup standard "C" local
     // (workaround for a bug in bitcode generation : http://lists.cs.uiuc.edu/pipermail/llvmbugs/2012-May/023530.html)
@@ -891,9 +889,7 @@ BasicTyped* global::genBasicTyped(Typed::VarType type)
     Typed::VarType new_type = ((type == Typed::kFloatMacro) && gFAUSTFLOAT2Internal) ? itfloat() : type;
 
     // If not defined, add the type in the table
-    if (gTypeTable.find(new_type) == gTypeTable.end()) {
-        gTypeTable[new_type] = new BasicTyped(new_type);
-    }
+    if (gTypeTable.find(new_type) == gTypeTable.end()) { gTypeTable[new_type] = new BasicTyped(new_type); }
     return gTypeTable[new_type];
 }
 
@@ -998,9 +994,7 @@ string global::makeDrawPathNoExt()
 
 string global::getFreshID(const string& prefix)
 {
-    if (gIDCounters.find(prefix) == gIDCounters.end()) {
-        gIDCounters[prefix] = 0;
-    }
+    if (gIDCounters.find(prefix) == gIDCounters.end()) { gIDCounters[prefix] = 0; }
     int n               = gIDCounters[prefix];
     gIDCounters[prefix] = n + 1;
     return subst("$0$1", prefix, T(n));
@@ -1012,6 +1006,12 @@ bool global::isDebug(const string& debug_val)
     return debug_var == debug_val;
 }
 
+bool global::isOpt(const string& opt_val)
+{
+    string opt_var = (getenv("FAUST_OPT")) ? string(getenv("FAUST_OPT")) : "";
+    return opt_var == opt_val;
+}
+
 /****************************************************************
  Command line tools and arguments
  *****************************************************************/
@@ -1139,11 +1139,11 @@ bool global::processCmdline(int argc, const char* argv[])
         } else if (isCmd(argv[i], "-vhdl-trace", "--vhdl-trace")) {
             gVHDLTrace = true;
             i += 1;
-            
+
         } else if (isCmd(argv[i], "-vhdl-float", "--vhdl-float")) {
             gVHDLFloatEncoding = true;
             i += 1;
-            
+
         } else if (isCmd(argv[i], "-vhdl-components", "--vhdl-components") && (i + 1 < argc)) {
             gVHDLComponentsFile = std::string(argv[i + 1]);
             i += 2;
@@ -1152,6 +1152,10 @@ bool global::processCmdline(int argc, const char* argv[])
             gFPGAMemory = std::atoi(argv[i + 1]);
             i += 2;
 
+        } else if (isCmd(argv[i], "-style", "--svgstyle")) {
+            gGlobal->gStyleFile = argv[i + 1];
+            i += 2;
+
         } else if (isCmd(argv[i], "-f", "--fold") && (i + 1 < argc)) {
             gFoldThreshold = std::atoi(argv[i + 1]);
             i += 2;
@@ -1425,9 +1429,7 @@ bool global::processCmdline(int argc, const char* argv[])
             } else {
                 char  temp[PATH_MAX + 1];
                 char* path = realpath(argv[i + 1], temp);
-                if (path) {
-                    gArchitectureDirList.push_back(path);
-                }
+                if (path) { gArchitectureDirList.push_back(path); }
             }
             i += 2;
 
@@ -1499,9 +1501,7 @@ bool global::processCmdline(int argc, const char* argv[])
 
         } else if (argv[i][0] != '-') {
             const char* url = argv[i];
-            if (checkURL(url)) {
-                gInputFiles.push_back(url);
-            }
+            if (checkURL(url)) { gInputFiles.push_back(url); }
             i++;
 
         } else {
@@ -1522,9 +1522,7 @@ bool global::processCmdline(int argc, const char* argv[])
     // Check options coherency
     // ========================
 
-    if (gInPlace && gVectorSwitch) {
-        throw faustexception("ERROR : '-inpl' option can only be used in scalar mode\n");
-    }
+    if (gInPlace && gVectorSwitch) { throw faustexception("ERROR : '-inpl' option can only be used in scalar mode\n"); }
 
 #if 0
     if (gOutputLang == "ocpp" && gVectorSwitch) {
@@ -1578,10 +1576,8 @@ bool global::processCmdline(int argc, const char* argv[])
     if (gInlineTable && gOutputLang != "cpp") {
         throw faustexception("ERROR : -it can only be used with 'cpp' backend\n");
     }
-    if (gInlineTable && gMemoryManager) {
-        throw faustexception("ERROR : -it cannot be used with -mem\n");
-    }
-  
+    if (gInlineTable && gMemoryManager) { throw faustexception("ERROR : -it cannot be used with -mem\n"); }
+
     // gComputeMix check
     if (gComputeMix && gOutputLang == "ocpp") {
         throw faustexception("ERROR : -cm cannot be used with the 'ocpp' backend\n");
@@ -1622,9 +1618,7 @@ bool global::processCmdline(int argc, const char* argv[])
         throw faustexception("ERROR : -a can only be used with 'c', 'cpp', 'ocpp', 'rust' and 'cmajor' backends\n");
     }
 
-    if (gClassName == "") {
-        throw faustexception("ERROR : -cn used with empty string \n");
-    }
+    if (gClassName == "") { throw faustexception("ERROR : -cn used with empty string \n"); }
 
     if (err != 0) {
         stringstream error;
@@ -1647,17 +1641,13 @@ static string fxName(const string& filename)
     // determine position right after the last '/' or 0
     size_t p1 = 0;
     for (size_t i = 0; i < filename.size(); i++) {
-        if (filename[i] == '/') {
-            p1 = i + 1;
-        }
+        if (filename[i] == '/') { p1 = i + 1; }
     }
 
     // determine position of the last '.'
     size_t p2 = filename.size();
     for (size_t i = p1; i < filename.size(); i++) {
-        if (filename[i] == '.') {
-            p2 = i;
-        }
+        if (filename[i] == '.') { p2 = i; }
     }
 
     return filename.substr(p1, p2 - p1);
@@ -1697,9 +1687,7 @@ void global::initDirectories(int argc, const char* argv[])
     //-------------------------------------------------------------------------------------
     // init gImportDirList : a list of path where to search .lib files
     //-------------------------------------------------------------------------------------
-    if (char* envpath = getenv("FAUST_LIB_PATH")) {
-        gImportDirList.push_back(envpath);
-    }
+    if (char* envpath = getenv("FAUST_LIB_PATH")) { gImportDirList.push_back(envpath); }
 #ifdef INSTALL_PREFIX
     gImportDirList.push_back(INSTALL_PREFIX "/share/faust");
 #endif
@@ -1711,9 +1699,7 @@ void global::initDirectories(int argc, const char* argv[])
     //-------------------------------------------------------------------------------------
     // init gArchitectureDirList : a list of path where to search architectures files
     //-------------------------------------------------------------------------------------
-    if (char* envpath = getenv("FAUST_ARCH_PATH")) {
-        gArchitectureDirList.push_back(envpath);
-    }
+    if (char* envpath = getenv("FAUST_ARCH_PATH")) { gArchitectureDirList.push_back(envpath); }
     gArchitectureDirList.push_back(gFaustDirectory + "/architecture");
     gArchitectureDirList.push_back(gFaustSuperDirectory + "/architecture");
     gArchitectureDirList.push_back(gFaustSuperSuperDirectory + "/architecture");
@@ -1770,9 +1756,7 @@ void global::parseSourceFiles()
         throw faustexception("ERROR : no files specified; for help type \"faust --help\"\n");
     }
     for (s = gInputFiles.begin(); s != gInputFiles.end(); s++) {
-        if (s == gInputFiles.begin()) {
-            gMasterDocument = *s;
-        }
+        if (s == gInputFiles.begin()) { gMasterDocument = *s; }
         result = cons(importFile(tree(s->c_str())), result);
     }
 
@@ -1873,328 +1857,356 @@ static void enumBackends(ostream& out)
  Help and Version information
  *****************************************************************/
 
-static void printVersion()
+string global::printVersion()
 {
-    cout << "FAUST Version " << FAUSTVERSION << "\n";
-    cout << "Embedded backends: \n";
-    enumBackends(cout);
+    stringstream sstr;
+    sstr << "FAUST Version " << FAUSTVERSION << "\n";
+    sstr << "Embedded backends: \n";
+    enumBackends(sstr);
 #ifdef LLVM_BUILD
-    cout << "Build with LLVM version " << LLVM_VERSION << "\n";
+    sstr << "Build with LLVM version " << LLVM_VERSION << "\n";
 #endif
-    cout << "Copyright (C) 2002-2024, GRAME - Centre National de Creation Musicale. All rights reserved. \n";
+    sstr << "Copyright (C) 2002-2024, GRAME - Centre National de Creation Musicale. All rights reserved. \n";
+    return sstr.str();
 }
 
-static void printHelp()
+string global::printHelp()
 {
-    const char* tab  = "  ";
-    const char* line = "\n---------------------------------------\n";
+    stringstream sstr;
+    const char*  tab  = "  ";
+    const char*  line = "\n---------------------------------------\n";
 
-    cout << "FAUST compiler version " << FAUSTVERSION << "\n";
-    cout << "usage : faust [options] file1 [file2 ...]." << endl;
-    cout << "        where options represent zero or more compiler options \n\tand fileN represents a Faust source "
+    sstr << "FAUST compiler version " << FAUSTVERSION << "\n";
+    sstr << "usage : faust [options] file1 [file2 ...]." << endl;
+#ifndef EMCC
+    sstr << "        where options represent zero or more compiler options \n\tand fileN represents a Faust source "
             "file (.dsp extension)."
          << endl;
-
-    cout << endl << "Input options:" << line;
-    cout << tab << "-a <file>                               wrapper architecture file." << endl;
-    cout << tab << "-i        --inline-architecture-files   inline architecture files." << endl;
-    cout << tab << "-A <dir>  --architecture-dir <dir>      add the directory <dir> to the architecture search path."
+#endif
+    sstr << endl << "Input options:" << line;
+#ifndef EMCC
+    sstr << tab << "-a <file>                               wrapper architecture file." << endl;
+    sstr << tab << "-i        --inline-architecture-files   inline architecture files." << endl;
+    sstr << tab << "-A <dir>  --architecture-dir <dir>      add the directory <dir> to the architecture search path."
          << endl;
-    cout << tab << "-I <dir>  --import-dir <dir>            add the directory <dir> to the libraries search path."
+    sstr << tab << "-I <dir>  --import-dir <dir>            add the directory <dir> to the libraries search path."
          << endl;
-    cout << tab << "-L <file> --library <file>              link with the LLVM module <file>." << endl;
-
-    cout << endl << "Output options:" << line;
-    cout << tab << "-o <file>                               the output file." << endl;
-    cout << tab << "-e        --export-dsp                  export expanded DSP (with all included libraries)." << endl;
-    cout << tab << "-uim      --user-interface-macros       add user interface macro definitions to the output code."
+    sstr << tab << "-L <file> --library <file>              link with the LLVM module <file>." << endl;
+#endif
+#ifndef EMCC
+    sstr << endl << "Output options:" << line;
+    sstr << tab << "-o <file>                               the output file." << endl;
+    sstr << tab << "-e        --export-dsp                  export expanded DSP (with all included libraries)." << endl;
+    sstr << tab << "-uim      --user-interface-macros       add user interface macro definitions to the output code."
          << endl;
-    cout << tab << "-xml                                    generate an XML description file." << endl;
-    cout << tab << "-json                                   generate a JSON description file." << endl;
-    cout << tab
+    sstr << tab << "-xml                                    generate an XML description file." << endl;
+    sstr << tab << "-json                                   generate a JSON description file." << endl;
+    sstr << tab
          << "-O <dir>  --output-dir <dir>            specify the relative directory of the generated output code and "
             "of additional generated files (SVG, XML...)."
          << endl;
-
-    cout << endl << "Code generation options:" << line;
-    cout << tab << "-lang <lang> --language                 select output language," << endl;
-    cout << tab
+#endif
+    sstr << endl << "Code generation options:" << line;
+#ifndef EMCC
+    sstr << tab << "-lang <lang> --language                 select output language," << endl;
+    sstr << tab
          << "                                        'lang' should be c, cpp (default), cmajor, codebox, csharp, "
             "dlang, fir, interp, java, jax, jsfx, julia, llvm, "
             "ocpp, rust, vhdl or wast/wasm."
          << endl;
-    cout << tab
+#endif
+    sstr << tab
          << "-single     --single-precision-floats   use single precision floats for internal computations (default)."
          << endl;
-    cout << tab << "-double     --double-precision-floats   use double precision floats for internal computations."
+    sstr << tab << "-double     --double-precision-floats   use double precision floats for internal computations."
          << endl;
-    cout << tab << "-quad       --quad-precision-floats     use quad precision floats for internal computations."
+#ifndef EMCC
+    sstr << tab << "-quad       --quad-precision-floats     use quad precision floats for internal computations."
          << endl;
-    cout << tab << "-fx         --fixed-point               use fixed-point for internal computations." << endl;
-    cout << tab
+#endif
+    sstr << tab << "-fx         --fixed-point               use fixed-point for internal computations." << endl;
+    sstr << tab
          << "-es 1|0     --enable-semantics 1|0      use enable semantics when 1 (default), and simple multiplication "
             "otherwise."
          << endl;
-    cout << tab << "-lcc        --local-causality-check     check causality also at local level." << endl;
-    cout << tab << "-light      --light-mode                do not generate the entire DSP API." << endl;
-    cout << tab
+    sstr << tab << "-lcc        --local-causality-check     check causality also at local level." << endl;
+#ifndef EMCC
+    sstr << tab << "-light      --light-mode                do not generate the entire DSP API." << endl;
+    sstr << tab
          << "-clang      --clang                     when compiled with clang/clang++, adds specific #pragma for "
             "auto-vectorization."
          << endl;
-    cout << tab
+    sstr << tab
          << "-nvi        --no-virtual                when compiled with the C++ backend, does not add the 'virtual' "
             "keyword."
          << endl;
-    cout << tab << "-fp         --full-parentheses          always add parentheses around binops." << endl;
-    cout << tab << "-cir        --check-integer-range       check float to integer range conversion." << endl;
-    cout << tab << "-exp10      --generate-exp10            pow(10,x) replaced by possibly faster exp10(x)." << endl;
-    cout << tab << "-os         --one-sample                generate one sample computation (same as -os0)." << endl;
-    cout << tab << "-os0        --one-sample0               generate one sample computation (0 = separated control)."
+    sstr << tab << "-fp         --full-parentheses          always add parentheses around binops." << endl;
+    sstr << tab << "-cir        --check-integer-range       check float to integer range conversion." << endl;
+    sstr << tab << "-exp10      --generate-exp10            pow(10,x) replaced by possibly faster exp10(x)." << endl;
+    sstr << tab << "-os         --one-sample                generate one sample computation (same as -os0)." << endl;
+    sstr << tab << "-os0        --one-sample0               generate one sample computation (0 = separated control)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-os1        --one-sample1               generate one sample computation (1 = separated control and DSP "
             "struct)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-os2        --one-sample2               generate one sample computation (2 = separated control and DSP "
             "struct. Separation in short and long delay lines)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-os3        --one-sample3               generate one sample computation (3 = like 2 but with external "
             "memory pointers kept in the DSP struct)."
          << endl;
-    cout << tab << "-it         --inline-table              inline rdtable/rwtable code in the main class." << endl;
-
-    cout << tab << "-cm         --compute-mix               mix in outputs buffers." << endl;
-    cout << tab
+    sstr << tab << "-it         --inline-table              inline rdtable/rwtable code in the main class." << endl;
+    sstr << tab << "-cm         --compute-mix               mix in outputs buffers." << endl;
+    sstr << tab
          << "-ct         --check-table               check rtable/rwtable index range and generate safe access code "
             "[0/1: 1 by default]."
          << endl;
-    cout << tab
+    sstr << tab
          << "-cn <name>  --class-name <name>         specify the name of the dsp class to be used instead of mydsp."
          << endl;
-    cout << tab
+    sstr << tab
          << "-scn <name> --super-class-name <name>   specify the name of the super class to be used instead of dsp."
          << endl;
-    cout << tab << "-pn <name>  --process-name <name>       specify the name of the dsp entry-point instead of process."
+    sstr << tab << "-pn <name>  --process-name <name>       specify the name of the dsp entry-point instead of process."
          << endl;
-    cout << tab
-         << "-mcd <n>    --max-copy-delay <n>        use a copy delay up to max delay <n> and a dense delay above (ocpp only) "
+    sstr << tab
+         << "-mcd <n>    --max-copy-delay <n>        use a copy delay up to max delay <n> and a dense delay above "
+            "(ocpp only) "
             "or a ring buffer (defaut 16 samples)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-mdd <n>    --max-dense-delay <n>       use a dense delay up to max delay <n> (if enough density) and a "
             "ring "
             "buffer delay above (ocpp only, default 1024)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-mdy <n>    --min-density <n>           minimal density (100*number of delays/max delay) to use a dense "
             "delays "
             "(ocpp only, default 33)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-dlt <n>    --delay-line-threshold <n>  use a mask-based ring buffer delays up to max delay <n> and a "
             "select based ring buffers above (default INT_MAX samples)."
          << endl;
-    cout << tab
+#endif
+#ifndef EMCC
+    sstr << tab
          << "-mem        --memory-manager            allocate static in global state using a custom memory manager."
          << endl;
-    cout << tab
+#endif
+    sstr << tab
          << "-ftz <n>    --flush-to-zero <n>         code added to recursive signals [0:no (default), 1:fabs based, "
             "2:mask based (fastest)]."
          << endl;
-    cout << tab
+#ifndef EMCC
+    sstr << tab
          << "-rui        --range-ui                  whether to generate code to constraint vslider/hslider/nentry "
             "values "
             "in [min..max] range."
          << endl;
-    cout << tab
+    sstr << tab
          << "-fui        --freeze-ui                 whether to freeze vslider/hslider/nentry to a given value (init "
             "value by default)."
          << endl;
-    cout
+    sstr
         << tab
         << "-inj <f>    --inject <f>                inject source file <f> into architecture file instead of compiling "
            "a dsp file."
         << endl;
-    cout << tab << "-scal       --scalar                    generate non-vectorized code (default)." << endl;
-    cout << tab
+    sstr << tab << "-scal       --scalar                    generate non-vectorized code (default)." << endl;
+    sstr << tab
          << "-inpl       --in-place                  generates code working when input and output buffers are the same "
             "(scalar mode only)."
          << endl;
-    cout << tab << "-vec        --vectorize                 generate easier to vectorize code." << endl;
-    cout << tab << "-vs <n>     --vec-size <n>              size of the vector (default 32 samples)." << endl;
-    cout << tab
+    sstr << tab << "-vec        --vectorize                 generate easier to vectorize code." << endl;
+    sstr << tab << "-vs <n>     --vec-size <n>              size of the vector (default 32 samples)." << endl;
+    sstr << tab
          << "-lv <n>     --loop-variant <n>          [0:fastest, fixed vector size and a remaining loop (default), "
             "1:simple, variable vector size]."
          << endl;
-    cout << tab << "-omp        --openmp                    generate OpenMP pragmas, activates --vectorize option."
+    sstr << tab << "-omp        --openmp                    generate OpenMP pragmas, activates --vectorize option."
          << endl;
-    cout << tab << "-pl         --par-loop                  generate parallel loops in --openmp mode." << endl;
-    cout << tab
+    sstr << tab << "-pl         --par-loop                  generate parallel loops in --openmp mode." << endl;
+    sstr << tab
          << "-sch        --scheduler                 generate tasks and use a Work Stealing scheduler, activates "
             "--vectorize option."
          << endl;
-    cout << tab << "-ocl        --opencl                    generate tasks with OpenCL (experimental)." << endl;
-    cout << tab << "-cuda       --cuda                      generate tasks with CUDA (experimental)." << endl;
-    cout << tab << "-dfs        --deep-first-scheduling     schedule vector loops in deep first order." << endl;
-    cout << tab
+    sstr << tab << "-ocl        --opencl                    generate tasks with OpenCL (experimental)." << endl;
+    sstr << tab << "-cuda       --cuda                      generate tasks with CUDA (experimental)." << endl;
+    sstr << tab << "-dfs        --deep-first-scheduling     schedule vector loops in deep first order." << endl;
+    sstr << tab
          << "-g          --group-tasks               group single-threaded sequential tasks together when -omp or -sch "
             "is used."
          << endl;
-    cout << tab
+    sstr << tab
          << "-fun        --fun-tasks                 separate tasks code as separated functions (in -vec, -sch, or "
             "-omp mode)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-fm <file>  --fast-math <file>          use optimized versions of mathematical functions implemented in "
             "<file>, use 'faust/dsp/fastmath.cpp' when file is 'def', assume functions are defined in the architecture "
             "file when file is 'arch'."
          << endl;
-    cout << tab
+    sstr << tab
          << "-mapp       --math-approximation        simpler/faster versions of 'floor/ceil/fmod/remainder' functions."
          << endl;
-    cout << tab << "-noreprc    --no-reprc                  (Rust only) Don't force dsp struct layout to follow C ABI."
+    sstr << tab << "-noreprc    --no-reprc                  (Rust only) Don't force dsp struct layout to follow C ABI."
          << endl;
-    cout << tab << "-ns <name>  --namespace <name>          generate C++ or D code in a namespace <name>." << endl;
+    sstr << tab << "-ns <name>  --namespace <name>          generate C++ or D code in a namespace <name>." << endl;
 
-    cout << tab << "-vhdl-trace    --vhdl-trace             activate trace." << endl;
-    cout << tab << "-vhdl-float    --vhdl-float             uses IEEE-754 format for samples instead of fixed point."
+    sstr << tab << "-vhdl-trace    --vhdl-trace             activate trace." << endl;
+    sstr << tab << "-vhdl-float    --vhdl-float             uses IEEE-754 format for samples instead of fixed point."
          << endl;
-    cout << tab
+    sstr << tab
          << "-vhdl-components <file> --vhdl-components <file>    path to a file describing custom components for the "
             "VHDL backend."
          << endl;
-    cout << tab << "-fpga-mem <n>  --fpga-mem <n>           FPGA block ram max size, used in -os2/-os3 mode." << endl;
+    sstr << tab << "-fpga-mem <n>  --fpga-mem <n>           FPGA block ram max size, used in -os2/-os3 mode." << endl;
 
-    cout << tab << "-wi <n>     --widening-iterations <n>   number of iterations before widening in signal bounding."
+    sstr << tab << "-wi <n>     --widening-iterations <n>   number of iterations before widening in signal bounding."
          << endl;
 
-    cout << tab
+    sstr << tab
          << "-ni <n>     --narrowing-iterations <n>  number of iterations before stopping narrowing in signal bounding."
          << endl;
-
-    cout << endl << "Block diagram options:" << line;
-    cout << tab << "-ps        --postscript                 print block-diagram to a postscript file." << endl;
-    cout << tab << "-svg       --svg                        print block-diagram to a svg file." << endl;
-    cout << tab << "-sd        --simplify-diagrams          try to further simplify diagrams before drawing." << endl;
-    cout << tab << "-drf       --draw-route-frame           draw route frames instead of simple cables." << endl;
-    cout << tab
+#endif
+#ifndef EMCC
+    sstr << endl << "Block diagram options:" << line;
+    sstr << tab << "-ps        --postscript                 print block-diagram to a postscript file." << endl;
+    sstr << tab << "-svg       --svg                        print block-diagram to a svg file." << endl;
+    sstr << tab << "-sd        --simplify-diagrams          try to further simplify diagrams before drawing." << endl;
+    sstr << tab << "-drf       --draw-route-frame           draw route frames instead of simple cables." << endl;
+    sstr << tab
          << "-f <n>     --fold <n>                   threshold to activate folding mode during block-diagram "
             "generation (default 25 elements)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-fc <n>    --fold-complexity <n>        complexity threshold to fold an expression in folding mode "
             "(default 2)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-mns <n>   --max-name-size <n>          threshold during block-diagram generation (default 40 char)."
          << endl;
-    cout << tab
+    sstr << tab
          << "-sn        --simple-names               use simple names (without arguments) during block-diagram "
             "generation."
          << endl;
-    cout << tab << "-blur      --shadow-blur                add a shadow blur to SVG boxes." << endl;
-    cout << tab << "-sc        --scaled-svg                 automatic scalable SVG." << endl;
+    sstr << tab << "-blur      --shadow-blur                add a shadow blur to SVG boxes." << endl;
+    sstr << tab << "-sc        --scaled-svg                 automatic scalable SVG." << endl;
 
-    cout << endl << "Math doc options:" << line;
-    cout << tab
+    sstr << endl << "Math doc options:" << line;
+    sstr << tab
          << "-mdoc       --mathdoc                   print math documentation of the Faust program in LaTeX format in "
             "a -mdoc folder."
          << endl;
-    cout << tab << "-mdlang <l> --mathdoc-lang <l>          if translation file exists (<l> = en, fr, ...)." << endl;
-    cout << tab << "-stripmdoc  --strip-mdoc-tags           strip mdoc tags when printing Faust -mdoc listings."
+    sstr << tab << "-mdlang <l> --mathdoc-lang <l>          if translation file exists (<l> = en, fr, ...)." << endl;
+    sstr << tab << "-stripmdoc  --strip-mdoc-tags           strip mdoc tags when printing Faust -mdoc listings."
          << endl;
 
-    cout << endl << "Debug options:" << line;
-    cout << tab << "-d          --details                   print compilation details." << endl;
-    cout << tab << "-time       --compilation-time          display compilation phases timing information." << endl;
-    cout << tab << "-flist      --file-list                 print file list (including libraries) used to eval process."
+    sstr << endl << "Debug options:" << line;
+    sstr << tab << "-d          --details                   print compilation details." << endl;
+    sstr << tab << "-time       --compilation-time          display compilation phases timing information." << endl;
+    sstr << tab << "-flist      --file-list                 print file list (including libraries) used to eval process."
          << endl;
-    cout << tab << "-tg         --task-graph                print the internal task graph in dot format." << endl;
-    cout << tab << "-sg         --signal-graph              print the internal signal graph in dot format." << endl;
-    cout << tab << "-norm       --normalized-form           print signals in normalized form and exit." << endl;
-    cout << tab
+    sstr << tab << "-tg         --task-graph                print the internal task graph in dot format." << endl;
+    sstr << tab << "-sg         --signal-graph              print the internal signal graph in dot format." << endl;
+    sstr << tab << "-norm       --normalized-form           print signals in normalized form and exit." << endl;
+    sstr << tab
          << "-me         --math-exceptions           check / for 0 as denominator and remainder, fmod, sqrt, log10, "
             "log, acos, asin functions domain."
          << endl;
-    cout << tab
+    sstr << tab
          << "-sts        --strict-select             generate strict code for 'selectX' even for stateless branches "
             "(both are computed)."
          << endl;
-    cout << tab << "-wall       --warning-all               print all warnings." << endl;
-    cout << tab << "-t <sec>    --timeout <sec>             abort compilation after <sec> seconds (default 120)."
+    sstr << tab << "-wall       --warning-all               print all warnings." << endl;
+    sstr << tab << "-t <sec>    --timeout <sec>             abort compilation after <sec> seconds (default 120)."
          << endl;
 
-    cout << endl << "Information options:" << line;
-    cout << tab << "-h          --help                      print this help message." << endl;
-    cout << tab << "-v          --version                   print version information and embedded backends list."
+    sstr << endl << "Information options:" << line;
+    sstr << tab << "-h          --help                      print this help message." << endl;
+    sstr << tab << "-v          --version                   print version information and embedded backends list."
          << endl;
-    cout << tab << "-libdir     --libdir                    print directory containing the Faust libraries." << endl;
-    cout << tab << "-includedir --includedir                print directory containing the Faust headers." << endl;
-    cout << tab << "-archdir    --archdir                   print directory containing the Faust architectures."
+    sstr << tab << "-libdir     --libdir                    print directory containing the Faust libraries." << endl;
+    sstr << tab << "-includedir --includedir                print directory containing the Faust headers." << endl;
+    sstr << tab << "-archdir    --archdir                   print directory containing the Faust architectures."
          << endl;
-    cout << tab << "-dspdir     --dspdir                    print directory containing the Faust dsp libraries."
+    sstr << tab << "-dspdir     --dspdir                    print directory containing the Faust dsp libraries."
          << endl;
-    cout << tab << "-pathslist  --pathslist                 print the architectures and dsp library paths." << endl;
+    sstr << tab << "-pathslist  --pathslist                 print the architectures and dsp library paths." << endl;
 
-    cout << endl << "Example:" << line;
-    cout << "faust -a jack-gtk.cpp -o myfx.cpp myfx.dsp" << endl;
+    sstr << endl << "Example:" << line;
+    sstr << "faust -a jack-gtk.cpp -o myfx.cpp myfx.dsp" << endl;
+#endif
+    return sstr.str();
 }
 
-void global::printLibDir()
+string global::printLibDir()
 {
-    cout << gFaustRootDir << kPSEP << LIBDIR << endl;
+    stringstream sstr;
+    sstr << gFaustRootDir << kPSEP << LIBDIR << endl;
+    return sstr.str();
 }
-void global::printIncludeDir()
+string global::printIncludeDir()
 {
-    cout << gFaustRootDir << kPSEP << "include" << endl;
+    stringstream sstr;
+    sstr << gFaustRootDir << kPSEP << "include" << endl;
+    return sstr.str();
 }
-void global::printArchDir()
+string global::printArchDir()
 {
-    cout << gFaustRootDir << kPSEP << "share" << kPSEP << "faust" << endl;
+    stringstream sstr;
+    sstr << gFaustRootDir << kPSEP << "share" << kPSEP << "faust" << endl;
+    return sstr.str();
 }
-void global::printDspDir()
+string global::printDspDir()
 {
-    cout << gFaustRootDir << kPSEP << "share" << kPSEP << "faust" << endl;
+    stringstream sstr;
+    sstr << gFaustRootDir << kPSEP << "share" << kPSEP << "faust" << endl;
+    return sstr.str();
 }
-void global::printPaths()
+string global::printPaths()
 {
-    cout << "FAUST dsp library paths:" << endl;
-    for (const auto& path : gImportDirList) cout << path << endl;
-    cout << "\nFAUST architectures paths:" << endl;
-    for (const auto& path : gArchitectureDirList) cout << path << endl;
-    cout << endl;
+    stringstream sstr;
+    sstr << "FAUST dsp library paths:" << endl;
+    for (const auto& path : gImportDirList) sstr << path << endl;
+    sstr << "\nFAUST architectures paths:" << endl;
+    for (const auto& path : gArchitectureDirList) sstr << path << endl;
+    sstr << endl;
+    return sstr.str();
 }
 
 void global::printDirectories()
 {
     if (gHelpSwitch) {
-        printHelp();
+        cout << printHelp();
         throw faustexception();
     }
     if (gVersionSwitch) {
-        printVersion();
+        cout << printVersion();
         throw faustexception();
     }
     if (gLibDirSwitch) {
-        printLibDir();
+        cout << printLibDir();
         throw faustexception();
     }
     if (gIncludeDirSwitch) {
-        printIncludeDir();
+        cout << printIncludeDir();
         throw faustexception();
     }
     if (gArchDirSwitch) {
-        printArchDir();
+        cout << printArchDir();
         throw faustexception();
     }
     if (gDspDirSwitch) {
-        printDspDir();
+        cout << printDspDir();
         throw faustexception();
     }
     if (gPathListSwitch) {
-        printPaths();
+        cout << printPaths();
         throw faustexception();
     }
 }
@@ -2245,9 +2257,7 @@ void Garbageable::operator delete(void* ptr)
 {
     // We may have cases when a pointer will be deleted during
     // a compilation, thus the pointer has to be removed from the list.
-    if (!global::gHeapCleanup) {
-        global::gObjectTable.remove(static_cast<Garbageable*>(ptr));
-    }
+    if (!global::gHeapCleanup) { global::gObjectTable.remove(static_cast<Garbageable*>(ptr)); }
     free(ptr);
 }
 
@@ -2263,9 +2273,7 @@ void Garbageable::operator delete[](void* ptr)
 {
     // We may have cases when a pointer will be deleted during
     // a compilation, thus the pointer has to be removed from the list.
-    if (!global::gHeapCleanup) {
-        global::gObjectTable.remove(static_cast<Garbageable*>(ptr));
-    }
+    if (!global::gHeapCleanup) { global::gObjectTable.remove(static_cast<Garbageable*>(ptr)); }
     free(ptr);
 }
 
@@ -2276,7 +2284,7 @@ void callFun(threaded_fun fun, void* arg)
     // No thread support in JavaScript
     fun(arg);
 #elif defined(_WIN32)
-    DWORD  id;
+    DWORD id;
     HANDLE thread = CreateThread(NULL, MAX_STACK_SIZE, LPTHREAD_START_ROUTINE(fun), arg, 0, &id);
     faustassert(thread != NULL);
     WaitForSingleObject(thread, INFINITE);
